Reviewers: Christian Plesner Hansen,

Description:
Correct documentation for security callbacks---1st parameter can be any  
object
actually.


Please review this at http://codereview.chromium.org/208008

SVN Base: http://v8.googlecode.com/svn/branches/bleeding_edge/

Affected files:
   M     include/v8.h


Index: include/v8.h
===================================================================
--- include/v8.h        (revision 2896)
+++ include/v8.h        (working copy)
@@ -1537,9 +1537,9 @@

  /**
   * Returns true if cross-context access should be allowed to the named
  * property with the given key on the global object.
   */
-typedef bool (*NamedSecurityCallback)(Local<Object> global,
+typedef bool (*NamedSecurityCallback)(Local<Object> host,
                                        Local<Value> key,
                                        AccessType type,
                                        Local<Value> data);
@@ -1547,9 +1547,9 @@

  /**
   * Returns true if cross-context access should be allowed to the indexed
  * property with the given index on the global object.
   */
-typedef bool (*IndexedSecurityCallback)(Local<Object> global,
+typedef bool (*IndexedSecurityCallback)(Local<Object> host,
                                          uint32_t index,
                                          AccessType type,
                                          Local<Value> data);



--~--~---------~--~----~------------~-------~--~----~
v8-dev mailing list
[email protected]
http://groups.google.com/group/v8-dev
-~----------~----~----~----~------~----~------~--~---
@@ -1537,9 +1537,9 @@
  /**
   * Returns true if cross-context access should be allowed to the named
- * property with the given key on the global object.
+ * property with the given key on the host object.
   */
@@ -1547,9 +1547,9 @@
  /**
   * Returns true if cross-context access should be allowed to the indexed
- * property with the given index on the global object.
+ * property with the given index on the host object.
   */

Reply via email to